﻿using System;
using System.Windows.Forms;
using Steema.TeeChart.Pocket;
using Steema.TeeChart.Styles;
using System.Drawing;
using System.Drawing.Imaging;
using Steema.TeeChart.Drawing;
using System.Reflection;

namespace ChartTestApp
{
    public partial class Form1 : Form
    {
        private Bitmap m_ChartBitmap;
        private TChart m_Chart;

        public Form1()
        {
            BackColor = Color.Gold;
            Width = 550;
            Height = 550;
            InitializeComponent();
            
            m_Chart = new TChart();
            m_Chart.Width = 500;
            m_Chart.Height = 500;

            m_Chart.Panel.Visible = false;
            m_Chart.Walls.Back.Visible = false;            
            
            Bar bar = new Bar();
            bar.Add(new double[] { 950 });
            //bar.Marks.Visible = false; This solves the drawing issue, but it's no solution since we want the value tooltips visible.
            m_Chart.Series.Add(bar);

            // Setting Automatic to True also draws the chart outside of its bounds.
            m_Chart.Axes.Left.Automatic = false;
            m_Chart.Axes.Left.Maximum = 950;

            m_ChartBitmap = new Bitmap(m_Chart.Width, m_Chart.Height);
        }

        protected override void OnPaint(PaintEventArgs e)
        {
            using (Graphics graphics = Graphics.FromImage(m_ChartBitmap))
            {
                ConfigureGraphics(graphics);

                graphics.Clear(Color.Fuchsia);

                m_Chart.Draw(graphics);
            }

            using (ImageAttributes attributes = new ImageAttributes())
            {
                attributes.SetColorKey(Color.Fuchsia, Color.Fuchsia);
                Rectangle bounds = new Rectangle(0, 0, m_Chart.Width, m_Chart.Height);
                e.Graphics.DrawImage(m_ChartBitmap, bounds, 0, 0, m_Chart.Width, m_Chart.Height, GraphicsUnit.Pixel, attributes);
                attributes.ClearColorKey();
            }
            
            base.OnPaint(e);
        }

        public static void ConfigureGraphics(Graphics graphics)
        {
            if (Environment.OSVersion.Platform != PlatformID.WinCE)
            {
                PropertyInfo propertyInfo = graphics.GetType().GetProperty("TextRenderingHint");
                if (propertyInfo != null)
                {
                    propertyInfo.SetValue(graphics, 1, null);
                }
            }
        }
    }
}